-- name: [CS] Dr. Neo Cortex
-- description: Crash Bandicoot's mortal enemy is after the Power Stars!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation

    Use this if you're curious on how anything here works >v<
]]

local TEXT_MOD_NAME = "Dr. Neo Cortex"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("cortex_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("cortex_icon") -- Located in "textures"

-- All Located in "sound"
local VOICETABLE_CORTEX = {
	--[CHAR_SOUND_OKEY_DOKEY] = '[CHAR_SOUND_OKEY_DOKEY] .ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = '[CHAR_SOUND_HERE_WE_GO]v2.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = '[CHAR_SOUND_PUNCH_WAH] - Punch 2.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = '[CHAR_SOUND_PUNCH_WAH] - Punch 2.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = '[CHAR_SOUND_PUNCH_HOO] - Punch 1.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'[CHAR_SOUND_EEUH] .ogg', '[CHAR_SOUND_HRMM] .ogg', '[CHAR_SOUND_PUNCH_WAH] - Punch 2.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = '[CHAR_SOUND_GROUND_POUND_WAH].ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'[CHAR_SOUND_TWIRL_BOUNCE].ogg', '[CHAR_SOUND_HAHA3] .ogg'}, -- Triple jump sounds
	[CHAR_SOUND_UH] = 'CHAR_SOUND_ATTACKED v2.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = '[CHAR_SOUND_PUNCH_YAH] - Punch 3.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'Silent.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = '[CHAR_SOUND_YAHOO].ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = '[CHAR_SOUND_HAHA3] .ogg', -- Long jump
	[CHAR_SOUND_DOH] = 'CHAR_SOUND_ATTACKED v2.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'Silent.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'Silent.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = '[CHAR_SOUND_WAAAOOOW].ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = '[CHAR_SOUND_TWIRL_BOUNCE].ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'Silent.ogg', 
	[CHAR_SOUND_HRMM] = '[CHAR_SOUND_HRMM] .ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = '[CHAR_SOUND_HERE_WE_GO]v1.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = '[CHAR_SOUND_SO_LONGA_BOWSER] v2.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = 'CHAR_SOUND_ATTACKED v2.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = '[CHAR_SOUND_PANTING].ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = '[CHAR_SOUND_ON_FIRE]v1.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'smw_yoshi_spit.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = '[CHAR_SOUND_PANTING].ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'Silent.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = '[CHAR_SOUND_PANTING]', -- Exhale
	[CHAR_SOUND_SNORING3] = 'Silent.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = '[CHAR_SOUND_PANTING].ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = '[CHAR_SOUND_PANTING].ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = '[CHAR_SOUND_PANTING].ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = '[CHAR_SOUND_DYING]v2.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = '[CHAR_SOUND_DROWNING] .ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = '[CHAR_SOUND_MAMA_MIA] .ogg' -- Booted out of level
}

-- All Located in "actors"
local CAPTABLE_CHAR = {
    normal = smlua_model_util_get_id("cortex_normal_cap_geo"),
    wing = smlua_model_util_get_id("cortex_wing_cap_geo"),
    metal = smlua_model_util_get_id("cortex_metal_cap_geo"),
    metalWing = smlua_model_util_get_id("custom_model_cap_wing_geo"),
}

local PALETTE_CHAR = {
    [PANTS]  = "ffffff",
    [SHIRT]  = "ffffff",
    [GLOVES] = "ffffff",
    [SHOES]  = "ffffff",
    [HAIR]   = "ffffff",
    [SKIN]   = "ffffff",
    [CAP]    = "ffffff",
}

--[[
-- All Located in "textures"
local healthMeter = {
    label = {
        left = get_texture_info("template-hp-back-left"),
        right = get_texture_info("template-hp-back-right"),
    },
    pie = {
        [1] = get_texture_info("template-hp-pie-1"),
        [2] = get_texture_info("template-hp-pie-2"),
        [3] = get_texture_info("template-hp-pie-3"),
        [4] = get_texture_info("template-hp-pie-4"),
        [5] = get_texture_info("template-hp-pie-5"),
        [6] = get_texture_info("template-hp-pie-6"),
        [7] = get_texture_info("template-hp-pie-7"),
        [8] = get_texture_info("template-hp-pie-8"),
    }
}
]]

--[[
    Note: If there are some functionalities you don't care
    to add such as palettes, you can freely remove the function
    for it, the only function you require is character_add
]]

local CSloaded = false
local function on_character_select_load()
    CT_CHAR = _G.charSelect.character_add("Dr. Neo Cortex", {"Crash Bandicoot's Arch Nemesis is after the Power Stars!", "Model from Crash Boom-Bang"}, "Garrulous64 & Voice by DaveAce", {r = 255, g = 200, b = 200}, E_MODEL_CUSTOM_MODEL, CT_MARIO, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_CORTEX)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    --_G.charSelect.character_add_health_meter(CT_CHAR, healthMeter)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CORTEX then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CORTEX then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)